#!/bin/bash
#
# Source : http://www.keepalived.org/software/keepalived-1.1.17.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#


#------------------( Set Package Variables )


soft='keepalived'
softversion='1.1.17'
packageversion='64.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="$CFLAGS"


#------------------( Set Configuration Options )

cd $src
./configure --disable-lvs-syncd --prefix=/usr --sysconfdir=/etc


#------------------( Make and Install Software )

make
make install DESTDIR=$dest


#------------------( Clean things )
rm -rf $dest/etc/rc.d/init.d
rm -rf $dest/etc/sysconfig
chmod 755 $dest/usr/sbin/keepalived
rm -rf $dest/etc/keepalived/keepalived.conf

#------------------( Create startup script )

cat << "EOF" > $dest/etc/rc.d/rc.keepalived.new
#!/bin/bash
#
## init script for keepalived

keepalived_start() {
        if [ -x /usr/sbin/keepalived ]; then
                echo -n "Starting keepalived :  "
                echo "/usr/sbin/keepalived -D"
                /usr/sbin/keepalived -D 2>/dev/null
        fi
}

keepalived_stop() {
        killall keepalived
}

keepalived_restart() {
        sh $0 stop
	sleep 1
        sh $0 start
}

case "$1" in
        'start')
                keepalived_start
                ;;
        'stop')
                keepalived_stop
                ;;
        'restart')
                keepalived_restart
                ;;
        *)
                echo "usage $0 start|stop|restart"
esac
EOF
chmod 644 $dest/etc/rc.d/rc.keepalived.new

mkdir $dest/etc/rc.d/desc.d
echo keepalived:The VRRP High Availability daemon:keepalived > $dest/etc/rc.d/desc.d/keepalived.txt
chown -R root.root $dest/etc/rc.d

#------------------( Create default config file )

echo "! Configuration File for keepalived

global_defs {
   notification_email {
     acassen@firewall.loc
     failover@firewall.loc
     sysadmin@firewall.loc
   }
   notification_email_from Alexandre.Cassen@firewall.loc
   smtp_server 192.168.200.1
   smtp_connect_timeout 30
   router_id LVS_DEVEL
}

vrrp_instance VI_1 {
    state MASTER
    interface eth0
    virtual_router_id 51
    priority 100
    advert_int 1
    authentication {
        auth_type PASS
        auth_pass 1111
    }
    virtual_ipaddress {
        192.168.200.16
        192.168.200.17
        192.168.200.18
    }
}" > $dest/etc/keepalived/keepalived.conf.new

#------------------ ( Create doinst.sh file )
mkdir $dest/install
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/rc.d/rc.keepalived
config etc/keepalived/keepalived.conf" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh

#------------------ Strip Executables (Comment out these lines if debugging info is needed) )

cd $dest
chown -R root:root $dest
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# add 'default' files
#
mkdir -p $dest/usr/doc/$soft-$softversion
cd $src
cp -a \
AUTHOR COPYING INSTALL README VERSION CONTRIBUTORS TODO doc/keepalived.conf.SYNOPSIS \
$dest/usr/doc/$soft-$softversion

#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
keepalived: High Availability VRRP daemon
keepalived:
keepalived: keepalived implements an independent VRRPv2 stack to handle
keepalived: network failover of machines.
keepalived: 
keepalived: 
keepalived: 
keepalived:
keepalived:
keepalived:
keepalived:
EOF


#------------------( Compress Man Pages )

( cd $dest/usr
  mv share/man .
  rm -rf share
  cd man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Create The *.dep File )


cd $dest
depfinder $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $dest.txz
#mv $package.txz ../$package.txz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.txz > $package.md5

# Create source file
echo "http://www.keepalived.org/software/keepalived-1.1.17.tar.gz" > $package.src
echo "http://download.zenwalk.org/people/emmanuel/$soft-$softversion/build-$soft.sh" >> $package.src
